/* ============================= C MeatAxe ==================================
   File:        $Id: $
   Comment:     Add two MeatAxe objects
   --------------------------------------------------------------------------
   (C) Copyright 2003 Michael Ringe, Lehrstuhl D fuer Mathematik,
   RWTH Aachen, Germany  <mringe@math.rwth-aachen.de>
   This program is free software; see the file COPYING for details.
   ========================================================================== */


#include "meataxe.h"

/* --------------------------------------------------------------------------
   Local data
   -------------------------------------------------------------------------- */

MTX_DEFINE_FILE_INFO 


/*@-----------------------------------------------------------------------------
[!] Add two objects.
[dest]   Object to add to.
[src]    Object to be added.
[return] |dest| or NULL on error.
[]
This function adds |src| to |dest|, overwriting the latter with the result.
No new object is created. Both objects must be compatible for addition, e.g.,
two matrices over the same field and with equal number of rows or columns.
------------------------------------------------------------------------------*/

MtxObject_t *MtxAdd(MtxObject_t *dest, const MtxObject_t *src)
{
    if (dest->Type == MTX_MATRIX && src->Type == MTX_MATRIX)
	return (MtxObject_t *) MatAdd((Matrix_t *)dest,(const Matrix_t *)src);
    else if (dest->Type == MTX_MATRIX && src->Type == MTX_MATRIX)
	return (MtxObject_t *) PolAdd((Poly_t *)dest,(const Poly_t *)src);
    MTX_ERROR2("Operation not implemented: [type %d] + [type %d]",
	dest->Type,src->Type);
    return dest;
}

