/* ============================= C MeatAxe ==================================
   File:        $Id: smatread.c,v 1.2 2003/04/09 18:12:39 hoffmant Exp $
   Comment:     Read a matrix from a file.
   --------------------------------------------------------------------------
   (C) Copyright 1998 Michael Ringe, Lehrstuhl D fuer Mathematik,
   RWTH Aachen, Germany  <mringe@math.rwth-aachen.de>
   Modified by Tom Hoffman, Mathematics Department, University of
   Arizona, USA <hoffmant@math.arizona.edu>
   This program is free software; see the file COPYING for details.
   ========================================================================== */


#include "meataxe.h"
#include <stdlib.h>

MTX_DEFINE_FILE_INFO




int SMatWrite(const SparseMatrix_t *mat, MtxFile_t *f)
{
    long hdr[5];
    long i;

    hdr[0] = -7;
    hdr[1] = mat->Nor;
    hdr[2] = mat->Noc;
    hdr[3] = mat->Field;
    hdr[4] = mat->NonZero;
    if (MfWriteLong(f,hdr,5) != 5) 
    {
	MTX_ERROR("Cannot read header");
	return -1;
    }
    FfSetField(mat->Field);
    FfSetNoc(mat->NonZero);
    for (i = 0; i < mat->Nor; ++i)
    {
	if (MfWriteRows(f,mat->Data+(i*mat->RowSize),1) != 1)
	    return -1;
	if (MfWriteLong(f,mat->Position + i * mat->NonZero, mat->NonZero)
		!= mat->NonZero)
	    return -1;
    }
    return 0;
}



int SMatSave(const SparseMatrix_t *mat, const char *fn)
{
    MtxFile_t *f;
    int i;

    if (!SMatIsValid(mat))
        return -1;
    if ((f = MfCreate(fn)) == NULL)
        return -1;
    i = SMatWrite(mat,f);
    MfClose(f);
    if (i != 0)
        MTX_ERROR1("Cannot write sparse matrix to %s",fn);
    return i;
}



